# Copyright (C) 2021 The MITRE Corporation. See the toplevel
# file LICENSE.txt for license terms.

from __future__ import print_function, absolute_import
import sys
Py3 = (sys.version_info[0] == 3)

# This file contains Python 2/3 compatibility elements. Many of
# these equivalences are the result of running python-future's
# excellent futurize.py tool and figuring out which bits we need.

# We also document, here, what we DON'T need.

# New-style classes: every class in Python 3 inherits from object,
# at least implicitly. This is not true in Python 2, so all
# classes must inherit from object explicitly to be cross-version
# compatible. There are three other differences that we can ignore.
# The first is that the __next__ method for iterators has been
# replaced by the builtin next() function. This capability is not yet
# used in the MAT core. The second is that the __unicode__ method
# now takes precedence over the __str__ method for converting objects
# strings; since str in Python 3 is the Python 2 unicode type, I simple
# need to make sure that __unicode__ in Python 3 calls the tostring
# method defined below. Third, the __nonzero__ method is computed
# in Python 3, in part, using the new __bool__ method. None of this
# is used in the MAT core.

# Strings and ints: str, bytes in Python 3 is unicode, str in
# Python 2. There are places where I need to deal with these.

if Py3:
    _unicodestring = str
    _strtypes = (str,)
    _toint = int
    _inttypes = (int,)
    _numtypes = (int, float)
    import json
    # If I use an encoding keyword in Python 3, it needs to be
    # ignored, because what I get back is a str (i.e., a Unicode string).
    def _jsondumps(obj, encoding = "utf-8", **kw):
        return json.dumps(obj, **kw)
else:
    _unicodestring = unicode
    _strtypes = (str, unicode)
    _toint = long
    _inttypes = (int, long)
    _numtypes = (int, long, float)
    import json
    # If I use an encoding keyword and ensure_ascii is false, and
    # I get back a string, I should try to decode it using the
    # encoding. Can this fail? Yes. The string may genuninely contain
    # byte sequences that happen to correspond to the encoded version
    # according to the encoding presented. Am I about to worry about this?
    # I don't see how I can.
    def _jsondumps(obj, ensure_ascii = True, encoding = "utf-8", **kw):
        r = json.dumps(obj, ensure_ascii = ensure_ascii, encoding = encoding, **kw)
        if type(r) is not unicode:
            r = r.decode(encoding)
        return r

# Dictionary views. keys(), items(), values() are views in Python 3,
# which means if you change the dictionary while you're reading the
# view, the view will change. The futurize.py utility wraps list()
# around these, but in Python 2, that's just extra memory wasted.
# So we have to review all the changes generated by futurize to see
# which ones are absolutely needed.


    



