/* Copyright (C) 2007 - 2018 The MITRE Corporation. See the toplevel
file LICENSE.txt for license terms. */

/* SQL schema for workspace db. */

CREATE TABLE document_info (
  doc_name TEXT PRIMARY KEY NOT NULL, /* name of the file */
  basename TEXT NOT NULL, /* visible basename */
  assigned_user TEXT, /* user assigned to document (may be null) */
  locked_by TEXT, /* user who's locked the document (may be null) */  
  status TEXT NOT NULL, /* one of "reconciled", "gold", "partially gold",
                           "partially corrected", "uncorrected", "unannotated" */
  lock_id TEXT, /* if locked, a lock ID for close/save */
  workflow_status TEXT NOT NULL, /* what's supposed to happen to it next */
  current_step TEXT NOT NULL, /* where it is in the workspace's workflow */
  last_touched_by TEXT, /* in the CURRENT STEP - updated by markgold and save */
  pristine INTEGER DEFAULT 0 /* this flag controls whether assignments can be made; default is 0 for backward compatibility */
);

/* This table records the review schedules. */

CREATE TABLE review_schedules (
  step_name TEXT PRIMARY KEY NOT NULL, /* a step in the workspace workflow */
  review_type TEXT NOT NULL, /* one of "human", "reconciliation", "reconciliation_with_crossvalidation" */
  similarity_profile TEXT /* if we're doing reconciliation, this is the profile to use */
);

/* This table stores the human review states. */

CREATE TABLE review_info (
  doc_name TEXT PRIMARY KEY NOT NULL, /* the doc_name from document_info */
  basename TEXT NOT NULL, /* the corresponding basename, for ease of removal */
  requesting_user TEXT NOT NULL, /* the user that caused the review to be done */
  reviewing_user TEXT, /* user who's locked the document (may be null) */  
  lock_id TEXT, /* if locked, a lock ID for close/save */
  repair_request INTEGER DEFAULT 0 /* if this is a repair request, this should be 1 */
);

/* Note that locking in reconciliation locks basenames,
   while locking in core locks documents. So they can't be managed
   together. */

CREATE TABLE reconciliation_info (
  basename TEXT NOT NULL, /* the visible basename - matches either a 
                             basename in the core table, or a docname,
                             depending on whether it's a scheduled or ad-hoc review */
  requesting_user TEXT NOT NULL, /* the user that caused the review to be done */
  reviewing_user TEXT, /* user who's locked the document (may be null) */
  lock_id TEXT /* if locked, a lock ID for close/save */
);

/* This new table tracks the mapping between reconciliation
   and core folders. Entries will be here when they're in any of the reconciliation
   or pre-reconciliation states: "awaiting crossvalidation", "in reconciliation",
   "awaiting reconciliation partner". */

CREATE TABLE reconciliation_to_core (
  reconciliation_basename TEXT NOT NULL, /* the basename in the reconciliation_info table */
  core_docname TEXT NOT NULL /* the docname in the core, maybe many for each basename */
);

/* I want to leave open the possibility of having users with no roles. */

CREATE TABLE users (
  user TEXT PRIMARY KEY NOT NULL
);

CREATE TABLE user_roles (
  user TEXT NOT NULL /* user name, not a primary key */,
  role TEXT NOT NULL /* a role for the user: annotator or reviewer */  
);

/* There will be exactly one row in this table. */

CREATE TABLE workspace_state (
  task TEXT NOT NULL /* the name of the task */,
  logging_enabled INTEGER DEFAULT 0 /* 1 if enabled, 0 otherwise */,
  prioritization_class TEXT NULL /* the name of a prioritization class */,
  max_old_models INTEGER DEFAULT 0 /* the number of old models to keep */,
  workspace_config TEXT NOT NULL /* the workspace config or workflow associated with the workspace */,
  language TEXT NOT NULL /* the language associated with the workspace */,
  similarity_profile TEXT /* the similarity profile to use for reconciliation */
);

/* Basename sets. This is many-to-many. */

CREATE TABLE basename_sets (
  basename TEXT NOT NULL /* a basename */,
  basename_set TEXT NOT NULL /* a basename set */
);
