import sys

if sys.version_info[0] < 2:
    raise Exception("Python version 1 not supported")
elif sys.version_info[0] == 2:
    if sys.version_info[1] < 7:
        raise Exception("Python 2.x must be Python 2.7")
elif sys.version_info[0] == 3:
    if sys.version_info[1] < 3:
        raise Exception("Python 3.x before 3.3 not supported")

# There's a hideous bug in shutil.copytree() in some releases, caused by copystat.
# So we're going to redefine it so that if it's called from copytree, it
# ignores the error. 

import shutil
_cpstat = shutil.copystat
def _newcpstat(*args, **kw):
    try:
        _cpstat(*args, **kw)
    except Exception as e:
        import traceback, os
        for f, lno, ctx, fncall in traceback.extract_stack():
            if (os.path.basename(f) == "shutil.py") and (ctx == "copytree"):
                return
        raise
shutil.copystat = _newcpstat

from . import Error
from . import Annotation
from . import AnnotationTree
from . import Document
from . import Operation
from . import PluginDocInstaller
from . import PropertyCache
from . import XMLNode
from . import Config
# We enforce this in the core package, because the MAT server is not
# yet available, and the jCarafe server mechanism doesn't work without it.
# Don't understand why this is needed.
# Config.MATConfig.configureFromSetting("JCARAFE_JAR_SERVER_MODE_AVAILABLE", "no")
from . import Command
from . import ExecutionContext
from . import Utilities
from . import DocumentIO
from . import XMLIO
from . import TaskUtilities
from . import ModelBuilder
from . import PluginMgr
from . import AttributeClassifier
from . import Tagger
from . import ToolChain
from . import Bootstrap
from . import WorkspaceDB # needs ws_db.sql
from . import WorkspaceLogger
# From this point forward, munkres is needed. MATConfig will
# update the path if the lib setting is updated.
from . import Pair # needs munkres
from . import Score # needs Pair
from . import ComparisonDocument # needs Pair
from . import Workspace # needs WorkspaceLogger, WorkspaceDB, Bootstrap
from . import CarafeTrain # needs Workspace, exp_template.xml
from . import WorkspaceExperiment # needs Workspace, Score, CarafeTrain
