####################################################################################################
### -----------------------------------------  NOTICE  ----------------------------------------- ###
###                                                                                              ###
### This software (or technical data) was produced for the U.S. Government under contract        ###
### 2015-14120200002-002, and is subject to the Rights in Data-General Clause 52.227-14 , ALT    ###
### IV (MAY 2014) or (DEC 2007).                                                                 ###
###                                                                                              ###
### © 2019 The MITRE Corporation. All Rights Reserved.                                           ###
###                                                                                              ###
### -------------------------------------------------------------------------------------------- ###
####################################################################################################

"""
Test functions for the ``score.py`` CLI. To use, call `pyest` from the root of the project.

Every function must start with ``test_``, and every class must start with ``Test``. For
convenvience, testing classes will test the correspinding class in the BP library.

Examples:

    def test_ans():
        assert 3 == 3

    class TestClass(object):

        def test_one(self):
            x = "this"
            assert "h" in x

        def test_two(self):
            x = "foo bar"
            with pytest.raises(AssertionError):
                assert hasattr(x, "check")
"""

__author__  = "Leland E. Vakarian <lsperl@mitre.org>"
__date__    = "30 July 2020"

import pytest

from lib import bp
import convert


def test_convert_abstract_determinism_1():
    """A simple test for determinism in the conversion process."""

    converted_bp_doc = convert.mat2bp(
        "tests/fixtures/abstract.en.test-1.mat.json",
        "Abstract",
        "tester"
    )

    expected_bp_doc = bp.BPDocument.from_json("tests/fixtures/abstract.en.test-1.bp.json")

    assert converted_bp_doc == expected_bp_doc, "Converter produced unexpected document!"


def test_convert_abstract_determinism_2():
    """A simple test for determinism in the conversion process."""

    converted_bp_doc = convert.mat2bp(
        "tests/fixtures/abstract.en.test-1.mat.json",
        "Abstract",
        "tester"
    )

    converted_bp_doc.serialize("tests/fixtures/abstract.en.test-2.bp.json", force=True)
    serialized_bp_doc = bp.BPDocument.from_json("tests/fixtures/abstract.en.test-2.bp.json")

    assert converted_bp_doc == serialized_bp_doc, "Serialized document changed!"


def test_merge_same_spansets():
    spanset_a = bp.BPDocumentSpanSet.from_dict({ 'ssid': 'a', 'spans': [{ 'string': 'b'} ]})
    spanset_b = bp.BPDocumentSpanSet.from_dict({ 'ssid': 'a', 'spans': [{ 'string': 'b'} ]})

    result = convert.__spansets_are_mergeable(spanset_a, spanset_b)

    assert result is False


def test_merge_different_spansets():
    spanset_a = bp.BPDocumentSpanSet.from_dict({ 'ssid': 'a', 'spans': [{ 'string': 'b'} ]})
    spanset_b = bp.BPDocumentSpanSet.from_dict({ 'ssid': 'b', 'spans': [{ 'string': 'c'} ]})

    result = convert.__spansets_are_mergeable(spanset_a, spanset_b)

    assert result is False


def test_merge_same_spans_spansets():
    span_a = { 'string': 'b'}
    spanset_a = bp.BPDocumentSpanSet('a', [span_a])
    spanset_b = bp.BPDocumentSpanSet('b', [span_a])

    result = convert.__spansets_are_mergeable(spanset_a, spanset_b)

    assert result is True
