####################################################################################################
### -----------------------------------------  NOTICE  ----------------------------------------- ###
###                                                                                              ###
### This software (or technical data) was produced for the U.S. Government under contract        ###
### 2015-14120200002-002, and is subject to the Rights in Data-General Clause 52.227-14 , ALT    ###
### IV (MAY 2014) or (DEC 2007).                                                                 ###
###                                                                                              ###
### © 2019 The MITRE Corporation. All Rights Reserved.                                           ###
###                                                                                              ###
### -------------------------------------------------------------------------------------------- ###
####################################################################################################

"""
Test functions for the ``lib/utils.py`` library. To use, call `pyest` from the root of the project.

Every function must start with ``test_``, and every class must start with ``Test``. For
convenvience, testing classes will test the correspinding class in the BP library.

Examples:

    def test_ans():
        assert 3 == 3

    class TestClass(object):

        def test_one(self):
            x = "this"
            assert "h" in x

        def test_two(self):
            x = "foo bar"
            with pytest.raises(AssertionError):
                assert hasattr(x, "check")
"""

__author__  = "Leland E. Vakarian <lsperl@mitre.org>"
__date__    = "29 June 2020"

import pytest

import MAT

from lib import utils


def test_levenshtein():
    """Looking for expected values."""

    assert utils.levenshtein("abc", "abc") == 0
    assert utils.levenshtein("", "") == 0

    assert utils.levenshtein("abc", "ab") == 1
    assert utils.levenshtein("ac", "abc") == 1
    assert utils.levenshtein("a", "") == 1
    assert utils.levenshtein("", "b") == 1

    assert utils.levenshtein("abcd", "ac") == 2
    assert utils.levenshtein("ac", "abcd") == 2
    assert utils.levenshtein("ab", "") == 2
    assert utils.levenshtein("", "cd") == 2

